==> kaffeine_1.0~pre3.orig.tar.gz: kaffeine-1.0-pre3/src/sqlhelper.cpp <==
/*
 * sqlhelper.cpp
 *
 * Copyright (C) 2009 Christoph Pfister <christophpfister@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include "sqlhelper.h"

#include <QCoreApplication>
#include <QSqlError>
#include <KDebug>
#include <KLocalizedString>
#include <KMessageBox>
#include <KStandardDirs>
#include "tablemodel.h"

SqlHelper::SqlHelper()
{
	database = QSqlDatabase::addDatabase("QSQLITE", "kaffeine");
	database.setDatabaseName(KStandardDirs::locateLocal("appdata", "sqlite.db"));

	timer.setInterval(5000);
	connect(&timer, SIGNAL(timeout()), this, SLOT(collectSubmissions()));
}

SqlHelper::~SqlHelper()
{
}

bool SqlHelper::createInstance()
{
	Q_ASSERT(instance == NULL);

	if (!QSqlDatabase::isDriverAvailable("QSQLITE")) {
		KMessageBox::queuedMessageBox(NULL, KMessageBox::Error,
			i18nc("message box", "Please install the Qt SQLite plugin."));
		return false;
	}

	instance = new SqlHelper();

	if (!instance->database.open()) {
		QString details = instance->database.lastError().databaseText();

		if (!details.isEmpty() && !details.endsWith('\n')) {
			details.append('\n');
		}

		details.append(instance->database.lastError().driverText());
		KMessageBox::queuedDetailedError(NULL,
			i18nc("message box", "Cannot open the SQLite database."), details);
		delete instance;
		instance = NULL;
		return false;
	}

	qAddPostRoutine(deleteInstance);
	return true;
}

SqlHelper *SqlHelper::getInstance()
{
	return instance;
}

QSqlQuery SqlHelper::prepare(const QString &statement)
{
	QSqlQuery query(database);
	query.setForwardOnly(true);

	if (!query.prepare(statement)) {
		kError() << query.lastError().text();
	}

	return query;
}

QSqlQuery SqlHelper::exec(const QString &statement)
{
	QSqlQuery query(database);
	query.setForwardOnly(true);

	if (!query.exec(statement)) {
		kError() << query.lastError().text();
	}

	return query;
}

void SqlHelper::exec(QSqlQuery &query)
{
	if (!query.exec()) {
		kError() << query.lastError().text();
	}
}

void SqlHelper::requestSubmission(SqlModelAdaptor *object)
{
	if (!timer.isActive()) {
		timer.start();
	}

	objects.append(object);
}

void SqlHelper::collectSubmissions()
{
	exec("BEGIN");

	for (int i = 0; i < objects.size(); ++i) {
		objects.at(i)->submit();
	}

	exec("COMMIT");
	timer.stop();
	objects.clear();
}

void SqlHelper::deleteInstance()
{
	delete instance;
	instance = NULL;
}

SqlHelper *SqlHelper::instance = NULL;

==> kaffeine_1.1.orig.tar.gz: kaffeine-1.1/src/sqlhelper.cpp <==
/*
 * sqlhelper.cpp
 *
 * Copyright (C) 2009 Christoph Pfister <christophpfister@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include "sqlhelper.h"

#include <QCoreApplication>
#include <QSqlError>
#include <KDebug>
#include <KLocalizedString>
#include <KMessageBox>
#include <KStandardDirs>
#include "sqltablemodel.h"

SqlHelper::SqlHelper()
{
	database = QSqlDatabase::addDatabase("QSQLITE", "kaffeine");
	database.setDatabaseName(KStandardDirs::locateLocal("appdata", "sqlite.db"));

	timer.setInterval(5000);
	connect(&timer, SIGNAL(timeout()), this, SLOT(collectSubmissions()));
}

SqlHelper::~SqlHelper()
{
}

bool SqlHelper::createInstance()
{
	Q_ASSERT(instance == NULL);

	if (!QSqlDatabase::isDriverAvailable("QSQLITE")) {
		KMessageBox::queuedMessageBox(NULL, KMessageBox::Error,
			i18nc("message box", "Please install the Qt SQLite plugin."));
		return false;
	}

	instance = new SqlHelper();

	if (!instance->database.open()) {
		QString details = instance->database.lastError().databaseText();

		if (!details.isEmpty() && !details.endsWith('\n')) {
			details.append('\n');
		}

		details.append(instance->database.lastError().driverText());
		KMessageBox::queuedDetailedError(NULL,
			i18nc("message box", "Cannot open the SQLite database."), details);
		delete instance;
		instance = NULL;
		return false;
	}

	qAddPostRoutine(deleteInstance);
	return true;
}

SqlHelper *SqlHelper::getInstance()
{
	return instance;
}

QSqlQuery SqlHelper::prepare(const QString &statement)
{
	QSqlQuery query(database);
	query.setForwardOnly(true);

	if (!query.prepare(statement)) {
		kError() << query.lastError().text();
	}

	return query;
}

QSqlQuery SqlHelper::exec(const QString &statement)
{
	QSqlQuery query(database);
	query.setForwardOnly(true);

	if (!query.exec(statement)) {
		kError() << query.lastError().text();
	}

	return query;
}

void SqlHelper::exec(QSqlQuery &query)
{
	if (!query.exec()) {
		kError() << query.lastError().text();
	}
}

void SqlHelper::requestSubmission(SqlTableModelInterface *object)
{
	if (!timer.isActive()) {
		timer.start();
	}

	objects.append(object);
}

void SqlHelper::collectSubmissions()
{
	exec("BEGIN");

	for (int i = 0; i < objects.size(); ++i) {
		objects.at(i)->submit();
	}

	exec("COMMIT");
	timer.stop();
	objects.clear();
}

void SqlHelper::deleteInstance()
{
	delete instance;
	instance = NULL;
}

SqlHelper *SqlHelper::instance = NULL;
